@@ -1,6 +1,7 @@
 """DataSource service implementation."""
 
 import json
+import mimetypes
 from typing import Literal, List, Union, Tuple, Optional, Dict, Any
 from pathlib import Path
 
@@ -15,6 +16,7 @@ from ..models.datasource import (
     BaseUpdateDataSourceRequest,
     FileDataSourceRequest,
 )
+from ..models.assistant import AssistantListResponse
 from ..utils import ApiRequestHandler
 
 
@@ -82,7 +84,10 @@ class DatasourceService:
                     content = f.read()
 
                 # Basic MIME type detection
-                mime_type = self._api.detect_mime_type(file_path)
+                mime_type = (
+                    mimetypes.guess_type(file_path.name)[0]
+                    or "application/octet-stream"
+                )
                 file_uploads.append(("files", (file_path.name, content, mime_type)))
 
             elif isinstance(file_item, tuple) and len(file_item) == 3:
@@ -161,16 +166,20 @@ class DatasourceService:
         params["sort_key"] = sort_key
         params["sort_order"] = sort_order
 
+        unified_filters = {}
         if datasource_types:
-            params["index_type"] = datasource_types
+            unified_filters["index_type"] = datasource_types
         if projects:
-            params["project"] = projects
+            unified_filters["project"] = projects
         if status:
-            params["status"] = status.value
+            unified_filters["status"] = status.value
         if owner:
-            params["created_by"] = owner
+            unified_filters["created_by"] = owner
         if filters:
-            params["filters"] = json.dumps(filters)
+            unified_filters.update(filters)
+        if unified_filters:
+            params["filters"] = json.dumps(unified_filters)
+
         return self._api.get("/v1/index", List[DataSource], params=params)
 
     def get(self, datasource_id: str) -> DataSource:
@@ -198,3 +207,21 @@ class DatasourceService:
             Deletion confirmation
         """
         return self._api.delete(f"/v1/index/{datasource_id}", dict)
+
+    def get_assistants_using_datasource(
+        self, datasource_id: str
+    ) -> List[AssistantListResponse]:
+        """Get list of assistants that are using this datasource.
+
+        Args:
+            datasource_id: ID of the datasource
+
+        Returns:
+            List of AssistantListResponse objects containing assistants using this datasource
+
+        Raises:
+            ApiError: If the datasource is not found or other API errors occur.
+        """
+        return self._api.get(
+            f"/v1/index/{datasource_id}/assistants", List[AssistantListResponse]
+        )
